@@ -177,12 +177,8 @@ htmlSetMetaEncoding(htmlDocPtr doc, const xmlChar *encoding) {
 	return(-1);
 
     if (encoding != NULL) {
-#ifdef HAVE_SNPRINTF
 	snprintf(newcontent, sizeof(newcontent), "text/html; charset=%s",
                 encoding);
-#else
-	sprintf(newcontent, "text/html; charset=%s", encoding);
-#endif
 	newcontent[sizeof(newcontent) - 1] = 0;
     }
 
@@ -663,7 +659,6 @@ htmlDocDumpMemory(xmlDocPtr cur, xmlChar**mem, int *size) {
     htmlDocContentDump(buf, cur);
     *mem = buf->content;
     *size = buf->use;
-    MEM_CLEANUP(buf, sizeof(xmlBuffer));
     xmlFree(buf);
 }
 
@@ -680,10 +675,13 @@ htmlDocDumpMemory(xmlDocPtr cur, xmlChar**mem, int *size) {
  * @doc:  the document
  * @encoding:  the encoding string
  * 
+ * TODO: check whether encoding is needed
+ *
  * Dump the HTML document DTD, if any.
  */
 static void
-htmlDtdDumpOutput(xmlOutputBufferPtr buf, xmlDocPtr doc, const char *encoding) {
+htmlDtdDumpOutput(xmlOutputBufferPtr buf, xmlDocPtr doc,
+	          const char *encoding ATTRIBUTE_UNUSED) {
     xmlDtdPtr cur = doc->intSubset;
 
     if (cur == NULL) {
@@ -717,7 +715,8 @@ htmlDtdDumpOutput(xmlOutputBufferPtr buf, xmlDocPtr doc, const char *encoding) {
  * Dump an HTML attribute
  */
 static void
-htmlAttrDumpOutput(xmlOutputBufferPtr buf, xmlDocPtr doc, xmlAttrPtr cur, const char *encoding) {
+htmlAttrDumpOutput(xmlOutputBufferPtr buf, xmlDocPtr doc, xmlAttrPtr cur,
+	           const char *encoding ATTRIBUTE_UNUSED) {
     xmlChar *value;
 
     if (cur == NULL) {
@@ -962,12 +961,15 @@ htmlDocContentDumpOutput(xmlOutputBufferPtr buf, xmlDocPtr cur, const char *enco
      */
     type = cur->type;
     cur->type = XML_HTML_DOCUMENT_NODE;
-    if (cur->intSubset != NULL)
+    if (cur->intSubset != NULL) {
         htmlDtdDumpOutput(buf, cur, NULL);
-    else {
+#if 0
+    /* Disabled for XSLT output */
+    } else {
 	/* Default to HTML-4.0 transitionnal @@@@ */
 	xmlOutputBufferWriteString(buf, "<!DOCTYPE HTML PUBLIC \"-//W3C//DTD HTML 4.0 Transitional//EN\" \"http://www.w3.org/TR/REC-html40/loose.dtd\">\n");
 
+#endif
     }
     if (cur->children != NULL) {
         htmlNodeListDumpOutput(buf, cur, cur->children, encoding);
@@ -976,7 +978,6 @@ htmlDocContentDumpOutput(xmlOutputBufferPtr buf, xmlDocPtr cur, const char *enco
     cur->type = (xmlElementType) type;
 }
 
-
 /************************************************************************
  *									*
  *		Saving functions front-ends				*
@@ -1131,6 +1132,8 @@ htmlSaveFileEnc(const char *filename, xmlDocPtr cur, const char *encoding) {
 		return(-1);
             htmlSetMetaEncoding(cur, (const xmlChar *) encoding);
 	}
+    } else {
+	htmlSetMetaEncoding(cur, (const xmlChar *) "UTF-8");
     }
 
     /*
