@@ -394,8 +394,13 @@ LIBXML_DLL_IMPORT extern int xmlDefaultBufferSize; /* default buffer size */
  * Handling Buffers.
  */
 
+void		xmlSetBufferAllocationScheme(xmlBufferAllocationScheme scheme);
+xmlBufferAllocationScheme	 xmlGetBufferAllocationScheme(void);
+
 xmlBufferPtr	xmlBufferCreate		(void);
 xmlBufferPtr	xmlBufferCreateSize	(size_t size);
+int		xmlBufferResize		(xmlBufferPtr buf,
+					 unsigned int size);
 void		xmlBufferFree		(xmlBufferPtr buf);
 int		xmlBufferDump		(FILE *file,
 					 xmlBufferPtr buf);
@@ -440,6 +445,7 @@ xmlNsPtr	xmlNewNs		(xmlNodePtr node,
 					 const xmlChar *href,
 					 const xmlChar *prefix);
 void		xmlFreeNs		(xmlNsPtr cur);
+void		xmlFreeNsList		(xmlNsPtr cur);
 xmlDocPtr 	xmlNewDoc		(const xmlChar *version);
 void		xmlFreeDoc		(xmlDocPtr cur);
 xmlAttrPtr	xmlNewDocProp		(xmlDocPtr doc,
