@@ -18,10 +18,19 @@ extern "C" {
  * your library and includes mismatch
  */
 extern void xmlCheckVersion(int version);
-#define LIBXML_DOTTED_VERSION "2.3.5"
-#define LIBXML_VERSION 20305
-#define LIBXML_VERSION_STRING "20305"
-#define LIBXML_TEST_VERSION xmlCheckVersion(20305);
+#define LIBXML_DOTTED_VERSION "2.3.6"
+#define LIBXML_VERSION 20306
+#define LIBXML_VERSION_STRING "20306"
+#define LIBXML_TEST_VERSION xmlCheckVersion(20306);
+
+/*
+ * Whether the trio support need to be configured in
+ */
+#if 0
+#define WITH_TRIO
+#else
+#define WITHOUT_TRIO
+#endif
 
 /*
  * Whether the FTP support is configured in
@@ -121,6 +130,15 @@ extern void xmlCheckVersion(int version);
 #endif
 #endif
 
+#ifdef __GNUC__
+#include <ansidecl.h>
+#ifndef ATTRIBUTE_UNUSED
+#define ATTRIBUTE_UNUSED
+#endif
+#else
+#define ATTRIBUTE_UNUSED
+#endif
+
 #ifdef __cplusplus
 }
 #endif /* __cplusplus */
