@@ -556,7 +556,7 @@ xmlPrintURI(FILE *stream, xmlURIPtr uri) {
  *
  * Make sure the xmlURI struct is free of content
  */
-void
+static void
 xmlCleanURI(xmlURIPtr uri) {
     if (uri == NULL) return;
 
@@ -596,7 +596,6 @@ xmlFreeURI(xmlURIPtr uri) {
     if (uri->opaque != NULL) xmlFree(uri->opaque);
     if (uri->authority != NULL) xmlFree(uri->authority);
     if (uri->query != NULL) xmlFree(uri->query);
-    MEM_CLEANUP(uri, sizeof(xmlURI));
     xmlFree(uri);
 }
 
@@ -1064,7 +1063,7 @@ xmlURIEscape(const xmlChar *str) {
  *
  * Returns 0 or the error code
  */
-int
+static int
 xmlParseURIFragment(xmlURIPtr uri, const char **str) {
     const char *cur = *str;
 
@@ -1090,7 +1089,7 @@ xmlParseURIFragment(xmlURIPtr uri, const char **str) {
  *
  * Returns 0 or the error code
  */
-int
+static int
 xmlParseURIQuery(xmlURIPtr uri, const char **str) {
     const char *cur = *str;
 
@@ -1116,7 +1115,7 @@ xmlParseURIQuery(xmlURIPtr uri, const char **str) {
  *
  * Returns 0 or the error code
  */
-int
+static int
 xmlParseURIScheme(xmlURIPtr uri, const char **str) {
     const char *cur;
 
@@ -1148,7 +1147,7 @@ xmlParseURIScheme(xmlURIPtr uri, const char **str) {
  *
  * Returns 0 or the error code
  */
-int
+static int
 xmlParseURIOpaquePart(xmlURIPtr uri, const char **str) {
     const char *cur;
 
@@ -1190,7 +1189,7 @@ xmlParseURIOpaquePart(xmlURIPtr uri, const char **str) {
  *
  * Returns 0 or the error code
  */
-int
+static int
 xmlParseURIServer(xmlURIPtr uri, const char **str) {
     const char *cur;
     const char *host, *tmp;
@@ -1324,7 +1323,7 @@ host_done:
  *
  * Returns 0 or the error code
  */
-int
+static int
 xmlParseURIRelSegment(xmlURIPtr uri, const char **str) {
     const char *cur;
 
@@ -1359,7 +1358,7 @@ xmlParseURIRelSegment(xmlURIPtr uri, const char **str) {
  *
  * Returns 0 or the error code
  */
-int
+static int
 xmlParseURIPathSegments(xmlURIPtr uri, const char **str, int slash) {
     const char *cur;
 
@@ -1439,7 +1438,7 @@ xmlParseURIPathSegments(xmlURIPtr uri, const char **str, int slash) {
  *
  * Returns 0 or the error code
  */
-int
+static int
 xmlParseURIAuthority(xmlURIPtr uri, const char **str) {
     const char *cur;
     int ret;
@@ -1489,7 +1488,7 @@ xmlParseURIAuthority(xmlURIPtr uri, const char **str) {
  *
  * Returns 0 or the error code
  */
-int
+static int
 xmlParseURIHierPart(xmlURIPtr uri, const char **str) {
     int ret;
     const char *cur;
@@ -1538,7 +1537,7 @@ xmlParseURIHierPart(xmlURIPtr uri, const char **str) {
  *
  * Returns 0 or the error code
  */
-int
+static int
 xmlParseAbsoluteURI(xmlURIPtr uri, const char **str) {
     int ret;
 
@@ -1570,7 +1569,7 @@ xmlParseAbsoluteURI(xmlURIPtr uri, const char **str) {
  *
  * Returns 0 or the error code
  */
-int
+static int
 xmlParseRelativeURI(xmlURIPtr uri, const char **str) {
     int ret = 0;
     const char *cur;
@@ -1712,7 +1711,7 @@ xmlParseURI(const char *str) {
 xmlChar *
 xmlBuildURI(const xmlChar *URI, const xmlChar *base) {
     xmlChar *val = NULL;
-    int ret, len, index, cur, out;
+    int ret, len, indx, cur, out;
     xmlURIPtr ref = NULL;
     xmlURIPtr bas = NULL;
     xmlURIPtr res = NULL;
@@ -1908,14 +1907,14 @@ xmlBuildURI(const xmlChar *URI, const xmlChar *base) {
      *    string.
      */
     if (ref->path != NULL && ref->path[0] != 0) {
-	index = 0;
+	indx = 0;
 	/*
 	 * Ensure the path includes a '/'
 	 */
 	if ((out == 0) && (bas->server != NULL))
 	    res->path[out++] = '/';
-	while (ref->path[index] != 0) {
-	    res->path[out++] = ref->path[index++];
+	while (ref->path[indx] != 0) {
+	    res->path[out++] = ref->path[indx++];
 	}
     }
     res->path[out] = 0;
