@@ -163,13 +163,8 @@ xlinkIsLink	(xmlDocPtr doc, xmlNodePtr node) {
 			ret = XLINK_TYPE_EXTENDED_SET;
 		} else {
 		    xmlChar buf[200];
-#ifdef HAVE_SNPRINTF
 		    snprintf((char *) buf, sizeof(buf), "%s:external-linkset",
 			     (char *) xlink->prefix);
-#else
-		    sprintf((char *) buf, "%s:external-linkset",
-			    (char *) xlink->prefix);
-#endif
                     buf[sizeof(buf) - 1] = 0;
 		    if (xmlStrEqual(role, buf))
 			ret = XLINK_TYPE_EXTENDED_SET;
